#!/usr/bin/perl
#
#  perl script to create all tables needed for both MicroCosm and Geodyn
#  processing.  The program first creates the GEODYN BIH tables and
#  corresponding report.  
#
# Programmer:  Terry Williams                Date:  Sept 29, 1999
#
#  Update:  Feb 11, 2002 to convert Geodyn table to VMSI table
#
#   *** CREATION OF VMSI TABLE DISABLED ***

# initialize environment and global variables
use Cwd 'chdir';
use IPC::Open2;

$bindir = "$ENV{'BINDIR'}";
chomp($bindir);
do ("${bindir}/init.pl");

if( @ARGV ) {
 if( $ARGV[0] =~ /^-h$/ ) {
   usage();
   exit(); 
 }
}

# create the GEODYN bih tables - the regular bih table and the 
# ionosphere bih table
$pid = open2('OUTDIR', 'INDIR', "${bindir}/create_geodyn_bih_table.pl");
$tmpdir = scalar<OUTDIR>;
wait;
close( OUTDIR );
close( INDIR );

chomp($tmpdir);

$tmpdir =~ /\= /;
$tmpname = $';

# write a message if program was successful
if(  (stat("${tmpname}/bih_tables_err"))[7] == 0 && 
     (stat("${tmpname}/master_bih_update.log"))[7] == 0 ) {
   print "\nThe GEODYN BIH table has been successfully updated.\n";
}

###########################################################################

sub usage {
  system "clear";
  print <<EOS;

create_bih_tables.pl is a perl script to create all tables needed for both 
MicroCosm and Geodyn processing.  The program first creates the GEODYN BIH
tables and corresponding report.  Next, a tables conversion program is run
converting the GEODYN BIH table to the VMSI table for the A1UTC section and
POLE section, only.

To execute: 
            create_bih_tables.pl 
             creates both the VMSI and Geodyn tables

            create_bih_tables.pl -h
             provides help on the execution and a brief description

EOS
}
