#!/usr/bin/perl
#
# Routine to obtain the date a file was last modified.
# The perl command stat returns an array giving the
# "vital statistics" of the file.  The 9th element
# gives the number of seconds from Jan 1, 1970 since
# the file was lasst modified.
#
# Programmer:  Terry Williams                 Date: Jan 8, 2002
#
# initialize environment and global variables
use Cwd 'chdir';
use IPC::Open2;

$bindir = "$ENV{'BINDIR'}";
chomp($bindir);
do ("${bindir}/init.pl");

# initialize the mjd since Jan 1, 1970
# unix counts the number of seconds since this date
$mjd_1970 = 40587;

# check if mode of program based on arguments entered
if( @ARGV ) {
 if( $ARGV[0] =~ /^-a$/ ) {
   get_params(\$file);
 } elsif( $ARGV[0] =~ /^-h$/ ) {
   usage();
   exit();
 } else {
  $file = shift;
 }
} else {
  usage();
  exit();
}

  $secs_past_1970 = (stat("$file"))[9];
  $days_past_1970 = int($secs_past_1970/86400.0);
  $mjd = $mjd_1970 + $days_past_1970;

  $compute_date = sprintf("%s/compute_date 'mjd_ymd' %s\n",${bindir},$mjd);
  $pid = open2('OUTPUT','INPUT',$compute_date);
  $date_last_modified = scalar(<OUTPUT>);
  wait;
  close (OUTPUT);
  close (INPUT);
  chomp($date_last_modified);

  print "$date_last_modified\n";

################################################################################
sub get_params {

  system "clear";

  $correct_flag = 1;

  while( $correct_flag == 1 ) {

    # Enter name of file
    print "Enter name of file for which to access date of last modification:\n";
    $file = <STDIN>;
    chomp($file);
    $ans = '';
    while( $ans !~ /^y/i && $ans !~ /^n/i ) {
      print "Is the above information correct? (y/n) \n";
      $ans = <STDIN>;
      chomp($ans);
      $ans =~ tr/A-Z/a-z/;
      if( $ans =~ "y" ) {
         $correct_flag = 0;
      }
    }

  }
}



################################################################################
sub usage {
 system "clear";
  print <<EOS;

file_date_modified.pl is a perl script 

To execute: 
        file_date_modified.pl \$file

        file_date_modified.pl -a
           prompts the user for the file name
           
        file_date_modified.pl -h
           provides help on the execution and a brief description 


EOS

}
