#!/usr/bin/perl
#
# Wrapper routine around ftpmget.pl to acquire the eop data files for a 
# Variables to access the host are found in the import_defaults file.
#
# Programmer:  Terry Williams                Date:  May 14, 1999
#   Modified: August 28, 2001 
#      added the import of the file eopc04.62-now used for
#      the geodyn bih table
#   Modified:  Feb 12, 2001
#      removed import and copy of files needed for the VMSI tables
#

# initialize environment and global variables
use Cwd 'chdir';
use IPC::Open2;

$bindir = "$ENV{'BINDIR'}";
chomp($bindir);
do ("${bindir}/init.pl");

# check mode 
if( @ARGV ) {
 if( $ARGV[0] =~ /^-h$/ ) {
   usage();
   exit();
 }
}

# Open the import defaults file
open (SYSM,"${sysfiles}/import_defaults")  || 
   die "can't open ${sysfiles}/import_defaults : $!\n";
flock(SYSM,$LOCK_EX);

# Find system variables needed for gps data import
while (<SYSM>) {
  @values = split(/\s+/, $_);
  if(/^tables_eop_host/) {
   $host_eop = $values[2];
  } elsif(/^tables_eop_rootdir/) {
   $remote_dir_eop = $values[2];
  } elsif(/^tables_bul_host/) {
   $host_bul = $values[2];
  } elsif(/^tables_bul_rootdir/) {
   $remote_dir_bul = $values[2];
  } elsif(/^tables_localdir/) {
   $local_dir = $values[2];
   $local_dir .= "/eop";
  } elsif(/^data_username/) {
   $user = $values[2];
  } else {
  }
}

# set up password
$pass = sprintf("%s@%s",${vpgs_user},$full_sys_name);
chomp($pass);
#print "values $host, $user, $pass\n";

flock(SYSM,$LOCK_UN);
close(SYSM);

# cd into the appropriate directory
$setdir = sprintf("%s/setdir.pl data $local_dir",${bindir});
$pid = open2('OUTDIR','INDIR',$setdir);
$fq_local_dir = scalar(<OUTDIR>);
wait;
close( OUTDIR );
close( INDIR );
chdir $fq_local_dir;

# define output log file
$output_file = "eop_import_log";

# get complete eop c04 series from 1962 to present
# new EOP files are based on IAU2000
#$files = "eopc04.62-now";
$files = "eopc04_IAU2000.62-now";

#call ftpmget which opens an ftp session to get eop data file
open(FILE, "|${bindir}/ftpmget.pl $host_eop $user $pass $remote_dir_eop $output_file - << End_Of_List > /dev/null
$files
End_Of_List");
close(FILE);

# define output log file
$output_file = "bul_import_log";

# file name is static, will change once file has been imported
#$remote_file = "ser7.dat";
$remote_file = "finals2000A.daily";

#call ftpmget which opens an ftp session to get eop bulletin a and b
open(FILE, "|${bindir}/ftpmget.pl $host_bul $user $pass $remote_dir_bul $output_file - << End_Of_List > /dev/null
$remote_file 
End_Of_List");

close(FILE);
wait;


###########################################################################

sub usage {
  system "clear";
  print <<EOS;

get_eop_data is a perl script to import eop data files twice weekly. Variables
used to determine the host machine and the directory for the data to import are
defined in the import defaults file. The script imports the permanent Earth
Orientation series which is the EOP(IERS) C 04 given in the 1997 system, and
Bulletin A (USNO series 7) containing the IERS rapid service and prediction
for EOP. 

To execute: get_eop_data.pl 
              automatic data import of eop files

            get_eop_data.pl -h
              provides help on the execution and a brief description

EOS
}
