#!/usr/bin/perl
#
# Wrapper routine around ftpmget.pl to acquire the remaining table files.
# Variables to access the host are found in the import_defaults file.
#
# Programmer:  Terry Williams                Date:  Sept 27, 1999
#   Modified: August 28, 2001  added the importing of UTC-TAI.history
#     for use by the GEODYN bih tables
#   Modified: Feb 12, 2002
#     removed import and copy of files used for the VMSI table
#

# initialize environment and global variables
use Cwd 'chdir';
use IPC::Open2;

$bindir = "$ENV{'BINDIR'}";
chomp($bindir);
do ("${bindir}/init.pl");

# check mode 
if( @ARGV ) {
 if( $ARGV[0] =~ /^-h$/ ) {
   usage();
   exit();
 }
}

# Open the import defaults file
open (SYSM,"${sysfiles}/import_defaults")  || 
   die "can't open ${sysfiles}/import_defaults : $!\n";
flock(SYSM,$LOCK_EX);

# Find import variables needed for gps data import
while (<SYSM>) {
  @values = split(/\s+/, $_);
  if(/^tables_eop_host/) {
   $host_eop = $values[2];
  } elsif(/^tables_eopbul_rootdir/) {
   $remote_dir_eop = $values[2];
   $remote_dir_eop .= "/bulc";
  } elsif(/^tables_kpap_host/) {
   $host_kpap = $values[2];
  } elsif(/^tables_kpap_rootdir/) {
   $remote_dir_kpap = $values[2];
  } elsif(/^tables_localdir/) {
   $local_dir = $values[2];
  } elsif(/^data_username/) {
   $user = $values[2];
  } else {
  }
}

# set up password
$pass = sprintf("%s@%s",${vpgs_user},$full_sys_name);
chomp($pass);
#print "values $host, $user, $pass\n";

flock(SYSM,$LOCK_UN);
close(SYSM);

# setup local dir for kp_ap information
$local_data_dir = sprintf("%s/sgo",$local_dir);

# cd into the appropriate directory
$setdir = sprintf("%s/setdir.pl data $local_data_dir",${bindir});
$pid = open2('OUTDIR','INDIR',$setdir);
$fq_local_dir = scalar(<OUTDIR>);
wait;
close( OUTDIR );
close( INDIR );
chdir $fq_local_dir;

# define output log file
$output_file = "kpap_import_log";

# create file name
# get current year and month
$year = `date +%Y`;
chomp($year);
$year -= 1;

# files no longer named final
#$year_file = "${year}.final\n";
$year_file = "${year}\n";

#call ftpmget which opens an ftp session to get kpap data file
open(FILE, "|${bindir}/ftpmget.pl $host_kpap $user $pass $remote_dir_kpap $output_file - << End_Of_List > /dev/null
$year_file
End_Of_List");
 
close(FILE);

# define output log file
$output_file = "bulc_import_log";

# setup local dir for bulletinc information
$local_data_dir = sprintf("%s/utc",$local_dir);
# cd into the appropriate directory
$setdir = sprintf("%s/setdir.pl data $local_data_dir",${bindir});
$pid = open2('OUTDIR','INDIR',$setdir);
$fq_local_dir = scalar(<OUTDIR>);
wait;
close( OUTDIR );
close( INDIR );
chdir $fq_local_dir;

$file = "UTC-TAI.history\n";

#call ftpmget which opens an ftp session to get sgo data file
open(FILE, "|${bindir}/ftpmget.pl $host_eop $user $pass $remote_dir_eop $output_file - << End_Of_List > /dev/null
$file
End_Of_List");
 
close(FILE);


###########################################################################

sub usage {
  system "clear";
  print <<EOS;

monitor_bih_table_files is a perl script to monitor the remaining files needed
for the VMSI table creation. The script imports the UTC-TAI.history which 
reports the history on UTC - TAI. In addition, the script monitors the final 
yearly file of Kp/Ap values.  The yearly file is updated during the year for 
up to 6 months. Prior to the existance of the yearly file, the monthly Kp/Ap 
values exist. 


To execute: monitor_bih_table_files.pl 
              monitors various files needed for the VMSI table creation

            monitor_bih_table_files.pl -h
              provides help on the execution and a brief description

EOS
}
