      subroutine dXdY_dpsideps(dmjd,cp1in,cp2in,cp1out,cp2out,opt)
!######################################################################
!
! Transformation of the celestial pole offsets (dpsi,deps) into
! the celestial pole offsets (dX,dY) and reciprocally.
!
!  input dmjd    : modified julian date
!          cp1in   : component 1 of the celestial pole offsets
!        cp2in   : component 2 of the celestial pole offsets
!        opt     : if opt = 1  (dpsi,deps)--> (dX,dY)
!                  if opt = 2  (dX,dY) --> (dpsi,deps)
!
!  output cp1out  : component 1 of the transformed celestial pole  
!                   offsets
!         cp2out  : component 2 of the transformed celestial pole  
!                   offsets
!
!  unit of the out put (cp1out,cp2out) are the same than the input  
!  (cp1in,cp2in)
!
!  Coded by Ch. Bizouard - December 2002 / September 2004
!######################################################################
      implicit none
      double precision dmjd,dt,psi_A,Chi_A,eps_A, secrad,pi,              
     .   deps,dpsi,dX,dY,cp1in,                                            
     .   cp2in,cp1out,cp2out
      integer opt

      pi = 4.d0 * datan(1.d0)
      secrad = pi/180.d0/3600.d0

      dt = (DMJD - 51544.5d0)/36525.d0 ! julian century

! Luni-solar precession
      psi_A =(5038.47875d0*dt-1.07259d0*dt**2-0.001147d0*dt**3)*secrad

! Planetary precession
      chi_A =(10.5526d0*dt-2.38064d0*dt**2-0.001125d0*dt**3)*secrad


      eps_A =(84381.448D0 -46.8402D0*dt -0.00059D0 * dt**2                
     .        +0.001813D0*dt**3)*secrad

      if (opt.eq.1) then
        dpsi = cp1in
        deps = cp2in

        dX = dpsi * dsin(eps_A) +(psi_A * dcos(eps_A) - chi_A) * deps
        dY = deps - (psi_A * dcos(eps_A) - chi_A)*dsin(eps_A)  * dpsi

        cp1out = dX
        cp2out = dY
      endif

      if (opt.eq.2) then
         dX = cp1in
         dY = cp2in

         dpsi =  dX/dsin(eps_A)                                           
     .             - dY*(psi_A*dcos(eps_A)-chi_A)/dsin(eps_A)
         deps =  dY                                                       
     .             + dX*(psi_A*dcos(eps_A)-chi_A)

         cp1out = dpsi
         cp2out = deps
      endif

      return
      end
